@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -87,7 +87,7 @@ sub _add_claims {
 
 sub _verify_claims {
   my ($payload, %args) = @_;
-  
+
   my $leeway = $args{leeway} || 0;
   my $now = time;
 
@@ -100,7 +100,7 @@ sub _verify_claims {
   elsif ($args{verify_iat} && $args{verify_iat}==1) {
     croak "JWT: iat claim required but missing"
   }
-  
+
   ### nbf
   if(defined $payload->{nbf}) {
     if (!defined $args{verify_nbf} || $args{verify_nbf}==1) {
@@ -110,7 +110,7 @@ sub _verify_claims {
   elsif ($args{verify_nbf} && $args{verify_nbf}==1) {
     croak "JWT: nbf claim required but missing"
   }
-    
+
   ### exp
   if(defined $payload->{exp}) {
     if (!defined $args{verify_exp} || $args{verify_exp}==1) {
@@ -130,7 +130,7 @@ sub _verify_claims {
       croak "JWT: iss claim check failed" unless $args{verify_iss}->($payload->{iss});
     }
   }
-  
+
   ### sub
   if(exists $payload->{sub}) {
     if (ref $args{verify_sub} eq 'Regexp') {
@@ -140,7 +140,7 @@ sub _verify_claims {
       croak "JWT: sub claim check failed" unless $args{verify_sub}->($payload->{sub});
     }
   }
-  
+
   ### aud
   if(exists $payload->{aud}) {
     if (ref $args{verify_aud} eq 'Regexp') {
@@ -150,7 +150,7 @@ sub _verify_claims {
       croak "JWT: aud claim check failed" unless $args{verify_aud}->($payload->{aud});
     }
   }
-  
+
   ### jti
   if(exists $payload->{jti}) {
     if (ref $args{verify_jti} eq 'Regexp') {
@@ -168,10 +168,11 @@ sub _payload_zip {
   if ($zip[0] eq 'deflate') {
     my $level = defined $zip[1] ? $zip[1] : 6;
     $header->{zip} = "DEF";
-    my $d = Compress::Raw::Zlib::Deflate->new(-Bufsize => 300, -Level => $level, -WindowBits => -MAX_WBITS());
+    my $d = Compress::Raw::Zlib::Deflate->new(-Bufsize => 1024, -WindowBits => -&MAX_WBITS(), -AppendOutput => 1, -Level => $level );
     my $output = '';
-    $d->deflate($payload, $output);
-    croak "JWT: deflate failed" unless $output;
+    $d->deflate($payload, $output) == Z_OK or croak "JWT: deflate failed";
+    $d->flush($output) == Z_OK             or croak "JWT: deflate/flush failed";
+    croak "JWT: deflate/output failed" unless $output;
     $payload = $output;
   }
   else {
@@ -183,7 +184,7 @@ sub _payload_zip {
 sub _payload_unzip {
   my ($payload, $z) = @_;
   if ($z eq "DEF") {
-    my $d = Compress::Raw::Zlib::Inflate->new(-Bufsize => 300, -WindowBits => -MAX_WBITS());
+    my $d = Compress::Raw::Zlib::Inflate->new(-Bufsize => 1024, -WindowBits => -&MAX_WBITS());
     my $output = '';
     $d->inflate($payload, $output);
     croak "JWT: inflate failed" unless $output;
@@ -635,7 +636,7 @@ Crypt::JWT - JSON Web Token (JWT, JWS, JWE) as defined by RFC7519, RFC7515, RFC7
 
 =head1 DESCRIPTION
 
-B<BEWARE:> experimental, unfinished, unstable, work in progress!!!
+B<BEWARE:> experimental, unfinished, unstable, work in progress!
 
 Implements B<JSON Web Token (JWT)> - L<https://tools.ietf.org/html/rfc7519>.
 The implementation covers not only B<JSON Web Signature (JWS)> - L<https://tools.ietf.org/html/rfc7515>,
@@ -643,6 +644,18 @@ but also B<JSON Web Encryption (JWE)> - L<https://tools.ietf.org/html/rfc7516>.
 
 The module implements B<all (100%) algorithms> defined in L<https://tools.ietf.org/html/rfc7518> - B<JSON Web Algorithms (JWA)>.
 
+=head1 EXPORT
+
+Nothing is exported by default.
+
+You can export selected functions:
+
+  use Crypt::JWT qw(decode_jwt encode_jwt);
+
+Or all of them at once:
+
+  use Crypt::JWT ':all';
+
 =head1 FUNCTIONS
 
 =head2 decode_jwt
@@ -653,7 +666,7 @@ Named arguments:
 
 =over
 
-=item * token
+=item token
 
 Mandatory argument, a string with either JWS or JWE JSON Web Token.
 
@@ -663,7 +676,7 @@ Mandatory argument, a string with either JWS or JWE JSON Web Token.
  ### JWE token example (5 segments)
  $t="eyJlbmMiOiJBMTI4R0NNIiwiYWxnIjoiQTEyOEtXIn0.UusxEbzhGkORxTRq0xkFKhvzPrXb9smw.VGfOuq0Fxt6TsdqLZUpnxw.JajIQQ.pkKZ7MHS0XjyGmRsqgom6w";
 
-=item * key
+=item key
 
 A key used for token decryption (JWE) or token signature validation (JWS). The value depends on C<alg> token header value.
 
@@ -709,23 +722,23 @@ A key used for token decryption (JWE) or token signature validation (JWS). The v
  ECDH-ES+A192KW      private ECC key, see ECDH-ES
  ECDH-ES+A256KW      private ECC key, see ECDH-ES
 
-=item * keypass
+=item keypass
 
 When 'key' parameter is an encrypted private RSA or ECC key this optional parameter may contain a password for private key decryption.
 
-=item * allow_none
+=item allow_none
 
 C<1> - accept JWS tokens with C<none> 'alg' header value (which means that token has no signature), B<BEWARE: DANGEROUS, UNSECURE!!!>
 
 C<0> (default) - do not allow JWS with C<none> 'alg' header value
 
-=item * ignore_signature
+=item ignore_signature
 
 C<1> - do not check signature on JWS tokens, B<BEWARE: DANGEROUS, UNSECURE!!!>
 
 C<0> (default) - check signature on JWS tokens
 
-=item * accepted_alg
+=item accepted_alg
 
 C<undef> (default) means accept all 'alg' algorithms except 'none' (for accepting 'none' use C<allow_none>)
 
@@ -741,7 +754,7 @@ C<Regexp> that has to match 'alg' algorithm name
  #or
  my $payload = decode_jwt(token=>$t, key=>$k, accepted_enc=>qr/^HS(256|384|512)$/);
 
-=item * accepted_enc
+=item accepted_enc
 
 C<undef> (default) means accept all 'enc' algorithms
 
@@ -757,7 +770,7 @@ C<Regexp> that has to match 'enc' algorithm name
  #or
  my $payload = decode_jwt(token=>$t, key=>$k, accepted_enc=>qr/^A(128|192|256)GCM$/);
 
-=item * decode_payload
+=item decode_payload
 
 C<0> - do not decode payload, return it as a raw string (octects).
 
@@ -765,7 +778,7 @@ C<1> - decode payload from JSON string, return it as perl hash ref (or array ref
 
 C<undef> (default) - if possible decode payload from JSON string, if decode_json fails return payload as a raw string (octets).
 
-=item * decode_header
+=item decode_header
 
 C<0> (default) - do not return decoded header as a return value of decode_jwt()
 
@@ -775,7 +788,7 @@ C<1> - return decoded header as a return value of decode_jwt()
  #or
  my ($header, $payload) = decode_jwt(token=>$t, key=>$k, decode_header=>1);
 
-=item * verify_iss
+=item verify_iss
 
 C<CODE ref> - subroutine (with 'iss' claim value passed as argument) should return C<true> otherwise verification fails
 
@@ -783,7 +796,7 @@ C<Regexp ref> - 'iss' claim value has to match given regexp otherwise verificati
 
 C<undef> (default) - do not verify 'iss' claim
 
-=item * verify_aud
+=item verify_aud
 
 C<CODE ref> - subroutine (with 'aud' claim value passed as argument) should return C<true> otherwise verification fails
 
@@ -791,7 +804,7 @@ C<Regexp ref> - 'aud' claim value has to match given regexp otherwise verificati
 
 C<undef> (default) - do not verify 'aud' claim
 
-=item * verify_sub
+=item verify_sub
 
 C<CODE ref> - subroutine (with 'sub' claim value passed as argument) should return C<true> otherwise verification fails
 
@@ -799,7 +812,7 @@ C<Regexp ref> - 'sub' claim value has to match given regexp otherwise verificati
 
 C<undef> (default) - do not verify 'sub' claim
 
-=item * verify_jti
+=item verify_jti
 
 C<CODE ref> - subroutine (with 'jti' claim value passed as argument) should return C<true> otherwise verification fails
 
@@ -807,7 +820,7 @@ C<Regexp ref> - 'jti' claim value has to match given regexp otherwise verificati
 
 C<undef> (default) - do not verify 'jti' claim
 
-=item * verify_iat
+=item verify_iat
 
 C<0> - ignore 'iat' claim
 
@@ -815,7 +828,7 @@ C<1> - require valid 'iat' claim
 
 C<undef> (default) - 'iat' claim must be valid if present
 
-=item * verify_nbf
+=item verify_nbf
 
 C<0> - ignore 'nbf' claim
 
@@ -823,7 +836,7 @@ C<1> - require valid 'nbf' claim
 
 C<undef> (default) - 'nbf' claim must be valid if present
 
-=item * verify_exp
+=item verify_exp
 
 C<0> - ignore 'exp' claim
 
@@ -831,7 +844,7 @@ C<1> - require valid 'exp' claim
 
 C<undef> (default) - 'exp' claim must be valid if present
 
-=item * leeway
+=item leeway
 
 Tolerance in seconds related to C<verify_exp>, C<verify_nbf>, C<verify_iat>. Default is C<0>.
 
@@ -859,7 +872,7 @@ HASH refs and ARRAY refs payloads are serialized as JSON strings
 
 =item alg
 
-Mandatory 'alg' header value.
+The 'alg' header value is mandatory for both JWE and JWS tokens.
 
 Supported JWE 'alg' algorithms:
 
@@ -899,7 +912,7 @@ Supported JWS algorithms:
 
 =item enc
 
-Mandatory 'enc' header value.
+The 'enc' header is mandatory for JWE tokens.
 
 Supported 'enc' algorithms:
 
