@@ -3,7 +3,7 @@ package Crypt::KeyWrap;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(aes_key_wrap aes_key_unwrap gcm_key_wrap gcm_key_unwrap pbes2_key_wrap pbes2_key_unwrap ecdh_key_wrap ecdh_key_unwrap ecdhaes_key_wrap ecdhaes_key_unwrap rsa_key_wrap rsa_key_unwrap)] );
@@ -357,6 +357,18 @@ Supported algorithms (all defined in RFC7518):
  ECDH-ES+A256KW         see: ecdhaes_key_wrap() + ecdhaes_key_unwrap()
  ECDH-ES                see: ecdh_key_wrap() + ecdh_key_unwrap()
 
+=head1 EXPORT
+
+Nothing is exported by default.
+
+You can export selected functions:
+
+  use Crypt::KeyWrap qw(aes_key_wrap gcm_key_wrap pbes2_key_wrap);
+
+Or all of them at once:
+
+  use Crypt::KeyWrap ':all';
+
 =head1 FUNCTIONS
 
 =head2 aes_key_wrap
